==> PythonCyc-2.0.tar.gz: PythonCyc-2.0/README.md <==
Copyright (c) 2014, SRI International

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

PythonCyc 2.0, January 2020
===========================

Overview
--------

An updated version of the original PythonCyc API from Mario Latendresse.

This module has been testes under Python 3.6 and Python 3.8, with examples
at https://github.com/networkbiolab/PythonCyc/tree/master/examples

Disclaimer: a number of functions remains broken.


PythonCyc 1.0, November 2014
============================

Overview
--------

The PythonCyc module provides a Python interface to a Pathway Tools
application running either locally or remotely. This module has been
designed to work on the three platforms supported by Pathway Tools:
Linux, Mac OS X, and Windows. Pathway Tools version 18.5 or
above is needed to use this module.

This module has been tested under Python 2.6 and 2.7, IPython 2.1 and
IPython notebook.

Installation
------------

Please, consult the HTML file tutorial.html under the doc directory of this
package for the installation instruction of PythonCyc and how to start
Pathway Tools to be able to use PythonCyc.

Documentation
-------------

1) For a tutorial on how to use PythonCyc, please consult the HTML file
tutorial.html under the doc directory of this package, or go directly
to the tutorial by clicking the following link https://github.com/latendre/PythonCyc/blob/master/doc/tutorial.md

2) For the API documentation of PythonCyc, please consult http://pythoncyc.readthedocs.org.

3) For the latest news about PythonCyc, please consult
http://bioinformatics.ai.sri.com/ptools/pythoncyc.html

Author
------

Mario Latendresse, latendre@AI.SRI.COM

License
-------

See file LICENSE.

Support
-------

For comments and/or bug reports, send an email to ptools-support@ai.sri.com.

Acknowledgments
---------------

Thanks to Eli Bogart to have inspired some implementation details of
PythonCyc via PyCyc, Tomer Altman for the Pathway Tools API
documentation, and Daniel Weaver for suggesting to implement some
specific functions and his design, with Kai Chen, of the beautiful PythonCyc logo.

==> PythonCyc-2.0.2.tar.gz: PythonCyc-2.0.2/README.md <==
Copyright (c) 2014, SRI International

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

PythonCyc 2.0, January 2020
===========================

Overview
--------

An updated version of the original PythonCyc API from Mario Latendresse.

This module has been tested under Python 3.6 and Python 3.8, with examples
at https://github.com/networkbiolab/PythonCyc/tree/master/examples

Disclaimer: a number of functions remains broken.


PythonCyc 1.0, November 2014
============================

Overview
--------

The PythonCyc module provides a Python interface to a Pathway Tools
application running either locally or remotely. This module has been
designed to work on the three platforms supported by Pathway Tools:
Linux, Mac OS X, and Windows. Pathway Tools version 18.5 or
above is needed to use this module.

This module has been tested under Python 2.6 and 2.7, IPython 2.1 and
IPython notebook.

Installation
------------

Please, consult the HTML file tutorial.html under the doc directory of this
package for the installation instruction of PythonCyc and how to start
Pathway Tools to be able to use PythonCyc.

Documentation
-------------

1) For a tutorial on how to use PythonCyc, please consult the HTML file
tutorial.html under the doc directory of this package, or go directly
to the tutorial by clicking the following link https://github.com/latendre/PythonCyc/blob/master/doc/tutorial.md

2) For the API documentation of PythonCyc, please consult http://pythoncyc.readthedocs.org.

3) For the latest news about PythonCyc, please consult
http://bioinformatics.ai.sri.com/ptools/pythoncyc.html

Author
------

Mario Latendresse, latendre@AI.SRI.COM

License
-------

See file LICENSE.

Support
-------

For comments and/or bug reports, send an email to ptools-support@ai.sri.com.

Acknowledgments
---------------

Thanks to Eli Bogart to have inspired some implementation details of
PythonCyc via PyCyc, Tomer Altman for the Pathway Tools API
documentation, and Daniel Weaver for suggesting to implement some
specific functions and his design, with Kai Chen, of the beautiful PythonCyc logo.
